@@ -293,13 +293,13 @@ public abstract class ContainerAnalysis  extends ClassAnalysis {
         Class returnType = m.getReturnType();
         // JBAS-4473, look for get<name>()
         String name = m.getName();
-        if (!(name.startsWith("get") && name.length() > "get".length()))
-            if (!(name.startsWith("is") && name.length() > "is".length())
-                    || !(returnType == Boolean.TYPE))
+        if (!(name.startsWith("get") && name.length() > "get".length())
+            && (!(name.startsWith("is") && name.length() > "is".length())
+                    || !(returnType == Boolean.TYPE)))
                 return false;
         if (returnType == Void.TYPE)
             return false;
-        if (m.getParameterTypes().length != 0)
+        if (m.getParameterCount() != 0)
             return false;
 
         return hasNonAppExceptions(m);
@@ -315,7 +315,7 @@ public abstract class ContainerAnalysis  extends ClassAnalysis {
             return false;
         if (m.getReturnType() != Void.TYPE)
             return false;
-        if (m.getParameterTypes().length != 1)
+        if (m.getParameterCount() != 1)
             return false;
         return hasNonAppExceptions(m);
     }
