@@ -202,7 +202,7 @@ public class WarMetaDataProcessor implements DeploymentUnitProcessor {
                 order.addAll(otherPos, jarsSet);
                 jarsSet.clear();
             }
-        } else if (orderings.size() > 0) {
+        } else if (!orderings.isEmpty()) {
             // Resolve relative ordering
             try {
                 resolveOrder(orderings, order);
@@ -367,10 +367,6 @@ public class WarMetaDataProcessor implements DeploymentUnitProcessor {
         }
     }
 
-    @Override
-    public void undeploy(final DeploymentUnit context) {
-    }
-
     /**
      * Utility class to associate the logical name with the JAR name, needed
      * during the order resolving.
